# Security Policy

## Supported Versions

Please see the table below for the supported versions of this project currently receiving security updates.

| Version | Supported          |
| ------- | ------------------ |
| > 0.1.x | :white_check_mark: |
| < 0.1.x | :x:                |

## Reporting a Vulnerability

Please do not report security vulnerabilities through public GitHub issues. 
Instead, please report them to the project maintainers privately.

If you discover a security vulnerability within this project, please send an e-mail to the maintainer. We will try to address the issue as soon as possible.

We will try to acknowledge your report within 48 hours, and will send a more detailed response indicating the next steps in handling your report. After the initial reply to your report, the security team will endeavor to keep you informed of the progress towards a fix and full announcement.
